package com.faraphel.tasks_valider.database

import androidx.room.Database
import androidx.room.RoomDatabase
import androidx.room.TypeConverters
import com.faraphel.tasks_valider.connectivity.task.session.TaskPermission
import com.faraphel.tasks_valider.connectivity.task.session.TaskSession
import com.faraphel.tasks_valider.database.api.entities.base.BaseApi
import com.faraphel.tasks_valider.database.api.entities.*
import com.faraphel.tasks_valider.database.converters.InstantConverter
import com.faraphel.tasks_valider.database.dao.GroupDao
import com.faraphel.tasks_valider.database.dao.GroupStudentDao
import com.faraphel.tasks_valider.database.dao.StudentDao
import com.faraphel.tasks_valider.database.dao.TaskDao
import com.faraphel.tasks_valider.database.dao.TaskGroupDao
import com.faraphel.tasks_valider.database.dao.TeacherDao
import com.faraphel.tasks_valider.database.entities.GroupEntity
import com.faraphel.tasks_valider.database.entities.GroupStudentEntity
import com.faraphel.tasks_valider.database.entities.StudentEntity
import com.faraphel.tasks_valider.database.entities.TaskEntity
import com.faraphel.tasks_valider.database.entities.TaskGroupEntity
import com.faraphel.tasks_valider.database.entities.TeacherEntity
import fi.iki.elonen.NanoHTTPD


/**
 * The database for the tasks application.
 * Contains the entities and the relations between them.
 */
@Database(
    entities = [
        GroupEntity::class,
        StudentEntity::class,
        TeacherEntity::class,
        TaskEntity::class,

        GroupStudentEntity::class,
        TaskGroupEntity::class,
    ],
    version = 1
)
@TypeConverters(
    InstantConverter::class
)
abstract class TaskDatabase : RoomDatabase() {
    abstract fun groupDao(): GroupDao
    abstract fun studentDao(): StudentDao
    abstract fun teacherDao(): TeacherDao
    abstract fun taskDao(): TaskDao

    abstract fun groupStudentDao(): GroupStudentDao
    abstract fun taskGroupDao(): TaskGroupDao
}
