package com.faraphel.tasks_valider.ui.screen.task

import android.app.Activity
import android.widget.Toast
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import com.faraphel.tasks_valider.connectivity.task.TaskClient
import com.faraphel.tasks_valider.database.entities.TaskGroupEntity
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken


val jsonParser = Gson()


/**
 * This screen let the user decide which student team he wants to interact with
 * @param client an HTTP client that can communicate with the server
 */
@Composable
fun TaskGroupScreen(activity: Activity, client: TaskClient) {
    val groups = remember { mutableStateOf<List<TaskGroupEntity>?>(null) }

    // title
    Text(text = "Task Group")

    // if the groups are not yet defined, refresh the list
    if (groups.value == null) {
        Thread { refreshGroups(activity, client, groups) }.start()
        return
    }

    // if the groups have already been defined, display them
    for (group in groups.value!!) {
        Text(text = group.toString())
    }
}


fun refreshGroups(activity: Activity, client: TaskClient, groups: MutableState<List<TaskGroupEntity>?>) {
    // try to obtain the list of groups
    val response = client.get("entities/group")

    // in case of error, notify it
    if (!response.isSuccessful) {
        Toast.makeText(activity, response.message, Toast.LENGTH_LONG).show()
        return
    }

    // parse the list of groups
    groups.value = jsonParser.fromJson(
        response.body.toString(),
        object : TypeToken<List<TaskGroupEntity>>(){}
    )
}